aboutsummaryrefslogtreecommitdiffstats
path: root/util/check-format-test-positives.c
diff options
context:
space:
mode:
authorDr. David von Oheimb <David.von.Oheimb@siemens.com>2020-06-07 14:53:20 +0200
committerDr. David von Oheimb <David.von.Oheimb@siemens.com>2020-07-20 11:17:34 +0200
commit174f4a4d6a8e54429732e01ea4448d2d08b2bf98 (patch)
tree495aed7b25ca3a2084170a1a2d274d571dcb3713 /util/check-format-test-positives.c
parentdc18781550d5df62074d0ad16680a6dda862df6e (diff)
downloadopenssl-174f4a4d6a8e54429732e01ea4448d2d08b2bf98.tar.gz
check-format.pl: Report empty lines only if -s (--sloppy-spc) is not used
Reviewed-by: Paul Dale <paul.dale@oracle.com> (Merged from https://github.com/openssl/openssl/pull/12270)
Diffstat (limited to 'util/check-format-test-positives.c')
-rw-r--r--util/check-format-test-positives.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/util/check-format-test-positives.c b/util/check-format-test-positives.c
index 40077925ff..7d9bbea5c7 100644
--- a/util/check-format-test-positives.c
+++ b/util/check-format-test-positives.c
@@ -334,11 +334,11 @@ void f_looong_body()
;
; /*@ 2 essentially empty lines before */
} /*@ function body length > 200 lines */
#if 0 /*@0 unclosed #if */
struct t { /*@0 unclosed brace at decl/block level */
enum { /*@0 unclosed brace at enum/expression level */
v = (1 /*@0 unclosed parenthesis */
- etyp /*@0 empty line follows just before EOF: */
+ etyp /*@0 empty line follows just before EOF, if !sloppy-spc: */
@@ -334,11 +334,11 @@ void f_looong_body()
;
- ; /*@ 2 essentially empty lines before */
+ ; /*@ 2 essentially empty lines before, if !sloppy-spc */
} /*@ function body length > 200 lines */
#if 0 /*@0 unclosed #if */